@@ -5,6 +5,7 @@
   Copyright (c) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
   Copyright (c) 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  Copyright (c) 2017 Allen Winter <winter@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -35,7 +36,7 @@
 */
 #include "stringify.h"
 
-#include <kcalcore/exceptions.h>
+#include <KCalCore/Exceptions>
 using namespace KCalCore;
 
 #include <KLocalizedString>
@@ -75,15 +76,16 @@ QString Stringify::incidenceSecrecy(Incidence::Secrecy secrecy)
         return i18nc("@item incidence access is by owner only", "Private");
     case Incidence::SecrecyConfidential:
         return i18nc("@item incidence access is by owner and a controlled group", "Confidential");
-    default: // to make compiler happy
-        return QString();
     }
+    return QString();
 }
 
 QStringList Stringify::incidenceSecrecyList()
 {
     const QStringList list {
-        incidenceSecrecy(Incidence::SecrecyPublic), incidenceSecrecy(Incidence::SecrecyPrivate), incidenceSecrecy(Incidence::SecrecyConfidential)
+        incidenceSecrecy(Incidence::SecrecyPublic),
+        incidenceSecrecy(Incidence::SecrecyPrivate),
+        incidenceSecrecy(Incidence::SecrecyConfidential)
     };
 
     return list;
@@ -110,9 +112,9 @@ QString Stringify::incidenceStatus(Incidence::Status status)
         return i18nc("@item journal is in final form", "Final");
     case Incidence::StatusX:
     case Incidence::StatusNone:
-    default:
         return QString();
     }
+    return QString();
 }
 
 QString Stringify::incidenceStatus(const Incidence::Ptr &incidence)
@@ -129,49 +131,37 @@ QString Stringify::attendeeRole(Attendee::Role role)
     switch (role) {
     case Attendee::Chair:
         return i18nc("@item chairperson", "Chair");
-        break;
-    default:
     case Attendee::ReqParticipant:
         return i18nc("@item participation is required", "Participant");
-        break;
     case Attendee::OptParticipant:
         return i18nc("@item participation is optional", "Optional Participant");
-        break;
     case Attendee::NonParticipant:
         return i18nc("@item non-participant copied for information", "Observer");
-        break;
     }
+    return {};
 }
 
 QString Stringify::attendeeStatus(Attendee::PartStat status)
 {
     switch (status) {
-    default:
     case Attendee::NeedsAction:
         return i18nc("@item event, to-do or journal needs action", "Needs Action");
-        break;
     case Attendee::Accepted:
         return i18nc("@item event, to-do or journal accepted", "Accepted");
-        break;
     case Attendee::Declined:
         return i18nc("@item event, to-do or journal declined", "Declined");
-        break;
     case Attendee::Tentative:
         return i18nc("@item event or to-do tentatively accepted", "Tentative");
-        break;
     case Attendee::Delegated:
         return i18nc("@item event or to-do delegated", "Delegated");
-        break;
     case Attendee::Completed:
         return i18nc("@item to-do completed", "Completed");
-        break;
     case Attendee::InProcess:
         return i18nc("@item to-do in process of being completed", "In Process");
-        break;
     case Attendee::None:
         return i18nc("@item event or to-do status unknown", "Unknown");
-        break;
     }
+    return {};
 }
 
 QString Stringify::errorMessage(const Exception &exception)
@@ -270,3 +260,20 @@ QString Stringify::scheduleMessageStatus(ScheduleMessage::Status status)
         return i18nc("@item unknown status", "Unknown Status: %1", int(status));
     }
 }
+
+QString Stringify::tzUTCOffsetStr(const QTimeZone &tz)
+{
+    int currentOffset = tz.offsetFromUtc(QDateTime::currentDateTimeUtc());
+    int absOffset = qAbs(currentOffset);
+    int utcOffsetHrs = absOffset / 3600;  // in hours
+    int utcOffsetMins = (absOffset % 3600) / 60;    // in minutes
+
+    const QString hrStr = QStringLiteral("%1").arg(utcOffsetHrs, 2, 10, QLatin1Char('0'));
+    const QString mnStr = QStringLiteral("%1").arg(utcOffsetMins, 2, 10, QLatin1Char('0'));
+
+    if (currentOffset < 0) {
+        return QStringLiteral("-%1:%2").arg(hrStr, mnStr);
+    } else {
+        return QStringLiteral("+%1:%2").arg(hrStr, mnStr);
+    }
+}
